@@ -1,10 +1,9 @@
 from typing import Any, Dict, List, Optional, Union
 
-from samtranslator.model import PropertyType, Resource
-from samtranslator.model.types import IS_DICT, is_type, one_of, IS_STR, list_of
-from samtranslator.model.intrinsics import ref, fnSub
+from samtranslator.model import GeneratedProperty, Resource
 from samtranslator.model.exceptions import ExpectedType, InvalidResourceException
-from samtranslator.schema.common import PassThrough
+from samtranslator.model.intrinsics import fnSub, ref
+from samtranslator.model.types import PassThrough
 from samtranslator.translator.arn_generator import ArnGenerator
 from samtranslator.utils.types import Intrinsicable
 from samtranslator.validator.value_validator import sam_expect
@@ -15,58 +14,91 @@ APIGATEWAY_AUTHORIZER_KEY = "x-amazon-apigateway-authorizer"
 class ApiGatewayV2HttpApi(Resource):
     resource_type = "AWS::ApiGatewayV2::Api"
     property_types = {
-        "Body": PropertyType(False, IS_DICT),
-        "BodyS3Location": PropertyType(False, IS_DICT),
-        "Description": PropertyType(False, IS_STR),
-        "FailOnWarnings": PropertyType(False, is_type(bool)),
-        "DisableExecuteApiEndpoint": PropertyType(False, is_type(bool)),
-        "BasePath": PropertyType(False, IS_STR),
-        "CorsConfiguration": PropertyType(False, IS_DICT),
+        "Body": GeneratedProperty(),
+        "BodyS3Location": GeneratedProperty(),
+        "Description": GeneratedProperty(),
+        "FailOnWarnings": GeneratedProperty(),
+        "DisableExecuteApiEndpoint": GeneratedProperty(),
+        "BasePath": GeneratedProperty(),
+        "Tags": GeneratedProperty(),
+        "CorsConfiguration": GeneratedProperty(),
     }
 
     runtime_attrs = {"http_api_id": lambda self: ref(self.logical_id)}
+    Tags: Optional[PassThrough]
+
+    def assign_tags(self, tags: Dict[str, Any]) -> None:
+        """Overriding default 'assign_tags' function in Resource class
+
+        Function to assign tags to the resource
+        :param tags: Tags to be assigned to the resource
+
+        """
+        if tags is not None and "Tags" in self.property_types:
+            self.Tags = tags
 
 
 class ApiGatewayV2Stage(Resource):
     resource_type = "AWS::ApiGatewayV2::Stage"
     property_types = {
-        "AccessLogSettings": PropertyType(False, IS_DICT),
-        "DefaultRouteSettings": PropertyType(False, IS_DICT),
-        "RouteSettings": PropertyType(False, IS_DICT),
-        "ClientCertificateId": PropertyType(False, IS_STR),
-        "Description": PropertyType(False, IS_STR),
-        "ApiId": PropertyType(True, IS_STR),
-        "StageName": PropertyType(False, one_of(IS_STR, IS_DICT)),
-        "Tags": PropertyType(False, IS_DICT),
-        "StageVariables": PropertyType(False, IS_DICT),
-        "AutoDeploy": PropertyType(False, is_type(bool)),
+        "AccessLogSettings": GeneratedProperty(),
+        "DefaultRouteSettings": GeneratedProperty(),
+        "RouteSettings": GeneratedProperty(),
+        "ClientCertificateId": GeneratedProperty(),
+        "Description": GeneratedProperty(),
+        "ApiId": GeneratedProperty(),
+        "StageName": GeneratedProperty(),
+        "Tags": GeneratedProperty(),
+        "StageVariables": GeneratedProperty(),
+        "AutoDeploy": GeneratedProperty(),
     }
 
     runtime_attrs = {"stage_name": lambda self: ref(self.logical_id)}
+    Tags: Optional[PassThrough]
+
+    def assign_tags(self, tags: Dict[str, Any]) -> None:
+        """Overriding default 'assign_tags' function in Resource class
+
+        Function to assign tags to the resource
+        :param tags: Tags to be assigned to the resource
+
+        """
+        if tags is not None and "Tags" in self.property_types:
+            self.Tags = tags
 
 
 class ApiGatewayV2DomainName(Resource):
     resource_type = "AWS::ApiGatewayV2::DomainName"
     property_types = {
-        "DomainName": PropertyType(True, IS_STR),
-        "DomainNameConfigurations": PropertyType(False, list_of(IS_DICT)),
-        "MutualTlsAuthentication": PropertyType(False, IS_DICT),
-        "Tags": PropertyType(False, IS_DICT),
+        "DomainName": GeneratedProperty(),
+        "DomainNameConfigurations": GeneratedProperty(),
+        "MutualTlsAuthentication": GeneratedProperty(),
+        "Tags": GeneratedProperty(),
     }
 
     DomainName: Intrinsicable[str]
     DomainNameConfigurations: Optional[List[Dict[str, Any]]]
     MutualTlsAuthentication: Optional[Dict[str, Any]]
-    Tags: Optional[Dict[str, Any]]
+    Tags: Optional[PassThrough]
+
+    def assign_tags(self, tags: Dict[str, Any]) -> None:
+        """Overriding default 'assign_tags' function in Resource class
+
+        Function to assign tags to the resource
+        :param tags: Tags to be assigned to the resource
+
+        """
+        if tags is not None and "Tags" in self.property_types:
+            self.Tags = tags
 
 
 class ApiGatewayV2ApiMapping(Resource):
     resource_type = "AWS::ApiGatewayV2::ApiMapping"
     property_types = {
-        "ApiId": PropertyType(True, IS_STR),
-        "ApiMappingKey": PropertyType(False, IS_STR),
-        "DomainName": PropertyType(True, IS_STR),
-        "Stage": PropertyType(True, IS_STR),
+        "ApiId": GeneratedProperty(),
+        "ApiMappingKey": GeneratedProperty(),
+        "DomainName": GeneratedProperty(),
+        "Stage": GeneratedProperty(),
     }
 
 
@@ -76,7 +108,7 @@ JwtConfiguration = Dict[str, Union[str, List[str]]]
 
 
 class ApiGatewayV2Authorizer:
-    def __init__(  # type: ignore[no-untyped-def]
+    def __init__(  # type: ignore[no-untyped-def] # noqa: PLR0913
         self,
         api_logical_id=None,
         name=None,
@@ -89,6 +121,7 @@ class ApiGatewayV2Authorizer:
         authorizer_payload_format_version=None,
         enable_simple_responses=None,
         is_aws_iam_authorizer=False,
+        enable_function_default_permissions=None,
     ):
         """
         Creates an authorizer for use in V2 Http Apis
@@ -104,6 +137,7 @@ class ApiGatewayV2Authorizer:
         self.authorizer_payload_format_version = authorizer_payload_format_version
         self.enable_simple_responses = enable_simple_responses
         self.is_aws_iam_authorizer = is_aws_iam_authorizer
+        self.enable_function_default_permissions = enable_function_default_permissions
 
         self._validate_input_parameters()
 
@@ -116,6 +150,13 @@ class ApiGatewayV2Authorizer:
         if authorizer_type == "REQUEST":
             self._validate_lambda_authorizer()
 
+        if enable_function_default_permissions is not None:
+            sam_expect(
+                enable_function_default_permissions,
+                api_logical_id,
+                f"Authorizers.{name}.EnableFunctionDefaultPermissions",
+            ).to_be_a_bool()
+
     def _get_auth_type(self) -> str:
         if self.is_aws_iam_authorizer:
             return "AWS_IAM"
@@ -167,6 +208,11 @@ class ApiGatewayV2Authorizer:
                 self.api_logical_id, "EnableSimpleResponses must be defined only for Lambda Authorizer."
             )
 
+        if self.enable_function_default_permissions is not None and authorizer_type != "REQUEST":
+            raise InvalidResourceException(
+                self.api_logical_id, "EnableFunctionDefaultPermissions must be defined only for Lambda Authorizer."
+            )
+
     def _validate_jwt_authorizer(self) -> None:
         if not self.jwt_configuration:
             raise InvalidResourceException(
@@ -224,7 +270,7 @@ class ApiGatewayV2Authorizer:
             partition = ArnGenerator.get_partition_name()
             resource = "lambda:path/2015-03-31/functions/${__FunctionArn__}/invocations"
             authorizer_uri = fnSub(
-                ArnGenerator.generate_arn(  # type: ignore[no-untyped-call]
+                ArnGenerator.generate_arn(
                     partition=partition, service="apigateway", resource=resource, include_account_id=False
                 ),
                 {"__FunctionArn__": self.function_arn},
