@@ -38,7 +38,8 @@ class RegionConfiguration:
         :return: True, if the service is supported in the region
         """
 
-        session = boto3.Session()
+        # Attempt to re-use an existing session if present.
+        session = boto3.Session() if not boto3.DEFAULT_SESSION else boto3.DEFAULT_SESSION
 
         if not region:
             # get the current region
@@ -47,11 +48,11 @@ class RegionConfiguration:
             # need to handle when region is None so that it won't break
             if region is None:
                 if ArnGenerator.BOTO_SESSION_REGION_NAME is not None:
-                    region = ArnGenerator.BOTO_SESSION_REGION_NAME  # type: ignore[unreachable]
+                    region = ArnGenerator.BOTO_SESSION_REGION_NAME
                 else:
                     raise NoRegionFound("AWS Region cannot be found")
 
         # check if the service is available in region
-        partition = session.get_partition_for_region(region)
+        partition = ArnGenerator.get_partition_name(region)
         available_regions = session.get_available_regions(service, partition_name=partition)
         return region in available_regions
